@@ -13,11 +13,10 @@ from djdantic.schemas import Error
 from djdantic.exceptions import AccessError
 
 try:
-    import sentry_sdk
-    from sentry_sdk.integrations import asgi as sentry_sdk_asgi
+    from sentry_sdk import last_event_id, capture_exception
 
 except ImportError:
-    sentry_sdk = None
+    capture_exception = last_event_id = lambda: None
 
 
 _logger = logging.getLogger(__name__)
@@ -25,10 +24,7 @@ _logger = logging.getLogger(__name__)
 
 def capture_exception(exc):
     _logger.exception(exc)
-    if not sentry_sdk:
-        return
-
-    return sentry_sdk.capture_exception(exc)
+    return capture_exception(exc)
 
 
 async def respond_details(request: Request, content: Any, status_code: int = 500, headers: dict = None):
@@ -36,7 +32,7 @@ async def respond_details(request: Request, content: Any, status_code: int = 500
         'detail': jsonable_encoder(content),
     }
 
-    event_id = sentry_sdk.last_event_id() or request.scope.get('sentry_event_id')
+    event_id = last_event_id() or request.scope.get('sentry_event_id')
     if event_id:
         response['event_id'] = event_id
 
